@@ -40,7 +40,7 @@ struct Killbots::Coordinator::AnimationStage {
           newScore(-1),
           newEnemyCount(-1),
           newEnergy(-1)
-    {};
+    {}
 
     bool isEmpty() const
     {
@@ -53,7 +53,7 @@ struct Killbots::Coordinator::AnimationStage {
                && newScore == -1
                && newEnemyCount == -1
                && newEnergy == -1;
-    };
+    }
 
     QList<Sprite *> spritesToCreate;
     QList<Sprite *> spritesToSlide;
@@ -318,7 +318,7 @@ void Killbots::Coordinator::nextAnimationStage()
     if (m_timeLine.state() != QTimeLine::Running && !m_queuedPopup->isVisible()) {
         m_stages.removeFirst();
 
-        if (m_stages.size()) {
+        if (!m_stages.isEmpty()) {
             startAnimationStage();
         } else {
             animationDone();
